@@ -11,7 +11,7 @@ use Cwd 'cwd';
 #x use Fcntl ':mode';
 #x use File::Copy;
 
-my @supported_mods = (qw(ftp sftp ssh2 local foreign fsp ftpssl));
+my @supported_mods = (qw(ftp sftp ssh2 local foreign openssh fsp ftpssl));
 my %haveit;
 my  $haveSFTPConstants = 0;
 
@@ -19,6 +19,7 @@ foreach my $imod (@supported_mods)
 {
 	$haveit{$imod} = 0;
 }
+$haveit{'local'} = 1;  #JWT:ADDED 20150123 - WE *ALWAYS* HAVE "local", SINCE NO EXTERNAL MODULE REQUIRED!
 
 my $bummer = ($^O =~ /Win/o) ? 1 : 0;
 
@@ -31,7 +32,7 @@ eval 'use Net::OpenSSH; use IO::Pty; $haveit{"openssh"} = 1; 1';
 eval 'use Net::FSP; $haveit{"fsp"} = 1; 1';
 eval 'use Net::FTPSSL; $haveit{"ftpssl"} = 1; 1';
 
-our $VERSION = '0.46';
+our $VERSION = '0.50';
 
 sub new
 {
@@ -56,9 +57,17 @@ sub new
 			delete $args{"xftp_$i"};
 		}
 	}
-
-	if ($pkg =~ /Net::FTPSSL/o && $haveit{'ftpssl'})
+#print "-???- pkg=$pkg= havit=".$haveit{'ftpssl'}."=\n";
+#foreach my $xxx (sort keys %haveit) { print "--haveit($xxx)=$haveit{$xxx}=\n"; };
+#	if ($pkg =~ /Net::FTPSSL/o && $haveit{'ftpssl'})
+	if ($pkg =~ /Net::FTPSSL/)
 	{
+		eval { require "Net/xFTP_FTPSSL.pm" };
+		if ($@ || !$haveit{'ftpssl'})
+		{
+			warn "xFTP:Could not require Net::xFTP_FTPSSL.pm module($@)!";
+			return undef;
+		}
 		foreach $i (keys %args)
 		{
 			foreach $j (@supported_mods)
@@ -74,16 +83,16 @@ sub new
 				}
 			}
 		}
-		eval { require "Net/xFTP_FTPSSL.pm" };
-		if ($@)
-		{
-			warn "xFTP:Could not require Net::xFTP_FTPSSL.pm module($@)!";
-			return;
-		}
 		$xftp = Net::xFTP::FTPSSL::new_ftpssl("${class}::FTPSSL", $pkg, $host, %args);
 	}
-	elsif ($pkg =~ /Net::FTP/o && $haveit{'ftp'})
+	elsif ($pkg =~ /Net::FTP/)
 	{
+		eval { require "Net/xFTP_FTP.pm" };
+		if ($@ || !$haveit{'ftp'})
+		{
+			warn "xFTP:Could not require Net::xFTP_FTP.pm module($@)!";
+			return undef;
+		}
 		foreach $i (keys %args)
 		{
 			foreach $j (@supported_mods)
@@ -99,16 +108,16 @@ sub new
 				}
 			}
 		}
-		eval { require "Net/xFTP_FTP.pm" };
-		if ($@)
-		{
-			warn "xFTP:Could not require Net::xFTP_FTP.pm module($@)!";
-			return;
-		}
 		$xftp = Net::xFTP::FTP::new_ftp("${class}::FTP", $pkg, $host, %args);
 	}
-	elsif ($pkg =~ /Net::SFTP::Foreign/o && $haveit{'foreign'})
+	elsif ($pkg =~ /Net::SFTP::Foreign/)
 	{
+		eval { require "Net/xFTP_Foreign.pm" };
+		if ($@ || !$haveit{'foreign'})
+		{
+			warn "xFTP:Could not require Net::xFTP_Foreign.pm module($@)!";
+			return undef;
+		}
 		foreach $i (keys %args)
 		{
 			foreach $j (@supported_mods)
@@ -124,16 +133,16 @@ sub new
 				}
 			}
 		}
-		eval { require "Net/xFTP_Foreign.pm" };
-		if ($@)
-		{
-			warn "xFTP:Could not require Net::xFTP_Foreign.pm module($@)!";
-			return;
-		}
 		$xftp = Net::xFTP::Foreign::new_foreign("${class}::Foreign", $pkg, $host, %args);
 	}
-	elsif ($pkg =~ /Net::SSH2/o && $haveit{'ssh2'})
+	elsif ($pkg =~ /Net::SSH2/)
 	{	
+		eval { require "Net/xFTP_SSH2.pm" };
+		if ($@ || !$haveit{'ssh2'})
+		{
+			warn "xFTP:Could not require Net::xFTP_SSH2.pm module($@)!";
+			return undef;
+		}
 		foreach $i (keys %args)
 		{
 			foreach $j (@supported_mods)
@@ -149,16 +158,16 @@ sub new
 				}
 			}
 		}
-		eval { require "Net/xFTP_SSH2.pm" };
-		if ($@)
-		{
-			warn "xFTP:Could not require Net::xFTP_SSH2.pm module($@)!";
-			return;
-		}
 		$xftp = Net::xFTP::SSH2::new_ssh2("${class}::SSH2", $pkg, $host, %args);
 	}
-	elsif ($pkg =~ /Net::SFTP/o && $haveit{'sftp'})
+	elsif ($pkg =~ /Net::SFTP/)
 	{
+		eval { require "Net/xFTP_SFTP.pm" };
+		if ($@ || !$haveit{'sftp'})
+		{
+			warn "xFTP:Could not require Net::xFTP_SFTP.pm module($@)!";
+			return undef;
+		}
 		foreach $i (keys %args)
 		{
 			foreach $j (@supported_mods)
@@ -174,17 +183,17 @@ sub new
 				}
 			}
 		}
-		eval { require "Net/xFTP_SFTP.pm" };
-		if ($@)
-		{
-			warn "xFTP:Could not require Net::xFTP_SFTP.pm module($@)!";
-			return;
-		}
 		$xftp = Net::xFTP::SFTP::new_sftp("${class}::SFTP", $pkg, $host, %args);
 		$xftp->{haveSFTPConstants} = $haveSFTPConstants  if ($xftp);
 	}
-	elsif ($pkg =~ /Net::FSP/o && $haveit{'fsp'})
+	elsif ($pkg =~ /Net::FSP/)
 	{	
+		eval { require "Net/xFTP_FSP.pm" };
+		if ($@ || !$haveit{'fsp'})
+		{
+			warn "xFTP:Could not require Net::xFTP_FSP.pm module($@)!";
+			return undef;
+		}
 		foreach $i (keys %args)
 		{
 			foreach $j (@supported_mods)
@@ -200,16 +209,16 @@ sub new
 				}
 			}
 		}
-		eval { require "Net/xFTP_FSP.pm" };
-		if ($@)
-		{
-			warn "xFTP:Could not require Net::xFTP_FSP.pm module($@)!";
-			return;
-		}
 		$xftp = Net::xFTP::FSP::new_fsp("${class}::FSP", $pkg, $host, %args);
 	}
-	elsif ($pkg =~ /Net::OpenSSH/o && $haveit{'openssh'})
+	elsif ($pkg =~ /Net::OpenSSH/)
 	{
+		eval { require "Net/xFTP_OpenSSH.pm" };
+		if ($@ || !$haveit{'openssh'})
+		{
+			warn "xFTP:Could not require Net::xFTP_OpenSSH.pm module($@)!";
+			return undef;
+		}
 		foreach $i (keys %args)
 		{
 			foreach $j (@supported_mods)
@@ -225,16 +234,16 @@ sub new
 				}
 			}
 		}
-		eval { require "Net/xFTP_OpenSSH.pm" };
-		if ($@)
-		{
-			warn "xFTP:Could not require Net::xFTP_OpenSSH.pm module($@)!";
-			return;
-		}
 		$xftp = Net::xFTP::OpenSSH::new_openssh("${class}::OpenSSH", $pkg, $host, %args);
 	}
-	elsif (!$pkg || $pkg =~ /local/io)
+	elsif (!$pkg || $pkg =~ /local/i)
 	{
+		eval { require "Net/xFTP_LOCAL.pm" };
+		if ($@)
+		{
+			warn "xFTP:Could not require Net::xFTP_LOCAL.pm module($@)!";
+			return undef;
+		}
 		foreach $i (keys %args)
 		{
 			foreach $j (@supported_mods)
@@ -250,17 +259,12 @@ sub new
 				}
 			}
 		}
-		eval { require "Net/xFTP_LOCAL.pm" };
-		if ($@)
-		{
-			warn "xFTP:Could not require Net::xFTP_LOCAL.pm module($@)!";
-			return undef;
-		}
 		$xftp = Net::xFTP::LOCAL::new_local("${class}::LOCAL", $pkg, $host, %args);
 	}
 	else
 	{
-		@_ = "Do not have package \"$pkg\"!";
+	$@ = "No such package \"$pkg\"!";
+		warn "xFTP:$@!";
 		return undef;
 	}
 
@@ -299,7 +303,8 @@ sub haveModules
 {
 	return { 'Net::FTP' => $haveit{'ftp'}, 'Net::SFTP' => $haveit{'sftp'},
 			'Net::SSH2' => $haveit{'ssh2'}, 'Net::SFTP::Foreign' => $haveit{'foreign'},
-			'Net::OpenSSH' => $haveit{'openssh'} };
+			'Net::OpenSSH' => $haveit{'openssh'}, 'Net::FSP' => $haveit{'fsp'}, 
+			'Net::FTPSSL' => $haveit{'ftpssl'}};
 }
 
 sub protocol
