@@ -12,7 +12,7 @@ sub new_local
 	my $xftp = bless { }, $subclass;
 
 	$@ = '';
-	$xftp->{cwd} = Cwd::cwd();
+	$xftp->{cwd} = Cwd::cwd();  #JWT:NOTE 20150123: DOES NOT RETURN A TRAILING "/" UNLESS "/"!
 	$xftp->{xftp} = 1;
 	return $xftp;
 }
@@ -23,7 +23,11 @@ sub new_local
 	{
 		my $self = shift;
 		my $cwd = shift || '/';
-
+		$cwd = Cwd::cwd() . '/' . $cwd  unless ($cwd =~ m#^(?:[a-zA-Z]\:|\/)#o);   #JWT:ADDED 20150123 TO HANDLE CASE WHERE USER SPECIFIES A RELATIVE PATH:
+		$cwd =~ s#\/\/#\/#o;
+		unless ($cwd =~ m#^(?:[A-Za-z]\:)?\/$#) {  #JWT:ADDED 20150123 TO ENSURE NO TRAILING SLASH (UNLESS "/" OR "C:/")
+			chop $cwd  if ($cwd =~ m#\/$#);
+		}
 		my $ok;
 		$self->{cwd} = $cwd;
 		$ok = 1;
@@ -39,11 +43,13 @@ sub new_local
 		for (my $i=0;$i<=1;$i++)
 		{
 			$args[$i] = $self->{cwd} . '/' . $args[$i]  unless ($args[$i] =~ m#^(?:[a-zA-Z]\:|\/)#o);
+			$args[$i] =~ s#\/\/#\/#o;
+
 		}
 		if ($self->isadir($args[1]))
 		{
 			my $filename = $1  if ($args[0] =~ m#([^\/]+)$#o);
-			$args[1] .= '/'  unless ($args[1] =~ m#\/$#o);
+			$args[1] .= '/'  unless ($args[1] =~ m#[\:\/]$#o);
 			$args[1] .= $filename;
 		}
 
@@ -94,16 +100,24 @@ sub ls
 	my $path = shift || '';
 	my $showall = shift || 0;
 	my @dirlist;
-	my $realpath = $path || Cwd::cwd();
-	if ($realpath eq '..')
+	my $realpath = $path || $self->{cwd} || Cwd::cwd();
+	if ($realpath =~ /^\./o)
 	{
-		$realpath = Cwd::cwd();
-		chop $realpath  if ($realpath =~ m#\/$#o);
-		$realpath =~ s#\/[^\/]+##o;
+		my $rp = $realpath;
+		$realpath = $self->{cwd} || Cwd::cwd();
+		chop $realpath  if ($realpath =~ m#[^\:]\/$#o);
+		$realpath =~ s#\/[^\/]+$#\/#o  if ($rp eq '..');
+	}
+	unless ($realpath =~ m#^(?:[a-zA-Z]\:|\/)#o) {
+		$realpath = $self->{cwd} . (($self->{cwd} =~ m#[\:\/]$#) ? '' : '/') . $realpath;
+	}
+	if ($self->{cwd} =~ m#^[a-zA-Z]\:# && $realpath !~ /\:/) {
+		$realpath = $self->{cwd} . (($self->{cwd} =~ m#\/$# || $realpath =~ m#^\/#) ? '' : '/') . $realpath;
+		$realpath =~ s#\/\/#\/#;
 	}
-	$realpath = $self->{cwd} . '/' . $realpath  unless ($realpath =~ m#^(?:[a-zA-Z]\:|\/)#o);
 	my $t;
 	@dirlist = ();
+print "-??????- CWD set to =".$self->{cwd}."= REALPATH=$realpath=\n";
 	if (opendir D, $realpath)
 	{
 		while ($t = readdir(D))
@@ -134,14 +148,21 @@ sub dir
 	my $path = shift || '';
 	my $showall = shift || 0;
 	my @dirlist;
-	my $realpath = $path || Cwd::cwd();
-	if ($realpath eq '..')
+	my $realpath = $path || $self->{cwd} || Cwd::cwd();
+	if ($realpath =~ /^\./o)
 	{
-		$realpath = Cwd::cwd();
-		chop $realpath  if ($realpath =~ m#\/$#o);
-		$realpath =~ s#\/[^\/]+##o;
+		my $rp = $realpath;
+		$realpath = $self->{cwd} || Cwd::cwd();
+		chop $realpath  if ($realpath =~ m#[^\:]\/$#o);
+		$realpath =~ s#\/[^\/]+$#\/#o  if ($rp eq '..');
+	}
+	unless ($realpath =~ m#^(?:[a-zA-Z]\:|\/)#o) {
+		$realpath = $self->{cwd} . (($self->{cwd} =~ m#[\:\/]$#) ? '' : '/') . $realpath;
+	}
+	if ($self->{cwd} =~ m#^[a-zA-Z]\:# && $realpath !~ /\:/) {
+		$realpath = $self->{cwd} . (($self->{cwd} =~ m#\/$# || $realpath =~ m#^\/#) ? '' : '/') . $realpath;
+		$realpath =~ s#\/\/#\/#;
 	}
-	$realpath = $self->{cwd} . '/' . $realpath  unless ($realpath =~ m#^(?:[a-zA-Z]\:|\/)#o);
 	my $t;
 	if ($self->{bummer})
 	{
@@ -237,6 +258,8 @@ sub get    #(Remote, => Local)
 	return undef  unless (@_ >= 1);
 	my @args = @_;
 	$args[0] = $self->{cwd} . '/' . $args[0]  unless ($args[0] =~ m#^(?:[a-zA-Z]\:|\/)#o);
+	$args[0] =~ s#\/\/#\/#o;
+
 	unless (@args >= 2)
 	{
 		if (ref(\$args[0]) =~ /GLOB/io)
@@ -299,6 +322,8 @@ sub put    #(LOCAL => REMOTE) SFTP returns OK=1 on SUCCESS.
 
 	my $ok;
 	$args[1] = $self->{cwd} . '/' . $args[1]  unless ($args[1] =~ m#^(?:[a-zA-Z]\:|\/)#o);
+	$args[1] =~ s#\/\/#\/#o;
+
 	if (ref(\$args[0]) =~ /GLOB/io)
 	{
 		my $buff;
@@ -337,6 +362,8 @@ sub delete       #RETURNED OK=2 WHEN LAST FAILED.
 
 	my $ok;
 	$path = $self->{cwd} . '/' . $path  unless ($path =~ m#^(?:[a-zA-Z]\:|\/)#o);
+	$path =~ s#\/\/#\/#o;
+
 	return  unless ($path);
 	#!!!!return ($_ == 1) ? 1 : undef;
 	return unlink($path) ? 1 : undef;
@@ -351,7 +378,10 @@ sub rename
 
 	my $ok;
 	$oldfile = $self->{cwd} . '/' . $oldfile  unless ($oldfile =~ m#^(?:[a-zA-Z]\:|\/)#o);
+	$oldfile =~ s#\/\/#\/#o;
 	$newfile = $self->{cwd} . '/' . $newfile  unless ($newfile =~ m#^(?:[a-zA-Z]\:|\/)#o);
+	$newfile =~ s#\/\/#\/#o;
+
 	$ok = rename($oldfile, $newfile);
 	unless ($ok)
 	{
@@ -373,6 +403,7 @@ sub mkdir
 	my $didRecursion = 0;
 	my $errored = 0;
 	$path = $self->{cwd} . '/' . $path  unless ($path =~ m#^(?:[a-zA-Z]\:|\/)#o);
+	$path =~ s#\/\/#\/#o;
 	while ($path)
 	{
 		$ok = mkdir $path;
@@ -414,6 +445,8 @@ sub rmdir
 
 	my $ok;
 	$path = $self->{cwd} . '/' . $path  unless ($path =~ m#^(?:[a-zA-Z]\:|\/)#o);
+	$path =~ s#\/\/#\/#o;
+
 	return undef  unless ($path);
 	$ok  = rmdir $path;
 	unless ($ok)
@@ -438,6 +471,8 @@ sub mdtm
 
 	my $ok;
 	$path = $self->{cwd} . '/' . $path  unless ($path =~ m#^(?:[a-zA-Z]\:|\/)#o);
+	$path =~ s#\/\/#\/#o;
+
 	eval { (undef, undef, undef, undef, undef, undef, undef, undef, undef,
 			$ok) = stat($path) };
 	return $@ ? undef : $ok;
@@ -450,6 +485,8 @@ sub size
 
 	my $ok;
 	$path = $self->{cwd} . '/' . $path  unless ($path =~ m#^(?:[a-zA-Z]\:|\/)#o);
+	$path =~ s#\/\/#\/#o;
+
 	eval { (undef, undef, undef, undef, undef, undef, undef, $ok) = stat($path) };
 	return $@ ? undef : $ok;
 }
@@ -461,6 +498,7 @@ sub isadir
 
 	my $ok;
 	$path = $self->{cwd} . '/' . $path  unless ($path =~ m#^(?:[a-zA-Z]\:|\/)#o);
+	$path =~ s#\/\/#\/#o;
 	return (-d $path) ? 1 : 0;
 }
 
@@ -472,6 +510,7 @@ sub chmod
 
 	my ($ok, $attrs);
 	$path = $self->{cwd} . '/' . $path  unless ($path =~ m#^(?:[a-zA-Z]\:|\/)#o);
+	$path =~ s#\/\/#\/#o;
 	eval "\$permissions = 0$permissions";
 	if ($@)
 	{
